/*-----------------------------------------------------------------
File "@Function.pro"
-------------------------------------------------------------------*/

Function {

	TimeInit		= 0.00e-3;		
	TimeDelta		= 2.00e-3;
	TimeEnd		= 20.0e-3;
	TimeTheta		= 1.0;

	slip 			= 0.00;

/******************************************************************************************/
/******************************************************************************************/

	mu0			= Pi*4e-7;
	munucleo		= 5000;

	nu[#{Conductor}]	= 1/mu0;
	nu[#{NoCondNoMag}]= 1/mu0;

//	nu[#{Nucleo}] 	= 1/(munucleo*mu0);

/******************************************************************************************/
/*******   This is for vector magnetic potential formulation with a Newton scheme   *******/
/******************************************************************************************/

	Steel_nu_b2     	= ListAlt[Steel_b2, Steel_nu] ;
  	nu_Steel[]      	= InterpolationAkima[$1]{List[Steel_nu_b2]} ;
  	nu_Nucleo[] 	= InterpolationLinear[$1]{List[Steel_nu_b2]} ;
  	dnudb2_Steel[]  	= dInterpolationAkima[$1]{List[Steel_nu_b2]} ;
  	h_Steel[] 		= nu_Steel[(SquNorm[$1])] * $1 ;
  	dhdb_Steel[] 	= TensorDiag[1,1,1] * nu_Steel[SquNorm[$1]] + 2*dnudb2_Steel[SquNorm[$1]] * SquDyadicProduct[$1] ;
  	h[Nucleo] 		= h_Steel[$1]; 
  	dhdb[Nucleo] 	= dhdb_Steel[$1];

/******************************************************************************************/
/******************************************************************************************/

  	NL_NbrMaxIter 	= 45;
  	NL_Eps 		= 5.0e-6;
  	NL_Relax[] 		= 0.95^($Iteration-1);	// 0.85;

/******************************************************************************************/
/******************************************************************************************/

	/*** Conductividad corregida por Temperatura ***/

	SigmaCuRec20	= 5.8e7;			// Cobre recocido 100% a 20C
	SigmaCuCom20	= SigmaCuRec20*0.973;	// Cobre comercial 97.3% a 20C
	SigmaAlum20		= SigmaCuRec20*0.61;	// Aluminio 61% a 20C

	TCuRec 	= 234.5;				// Cobre recocido 100%
	TCuCom 	= 241;				// Cobre comercial 97.3%
	TAlum  	= 228;				// Aluminio 61%
	
	t1 	= 20;						// Temperatura de referencia 20C
	t2 	= 75;						// Temperatura de trabajo 75C

	SigmaCuCom75 	= (TCuCom+t1)/(TCuCom+t2)*SigmaCuCom20;
	SigmaAlum75  	= (TAlum+t1)/(TAlum+t2)*SigmaAlum20;
	
	sigma[ConducEst] 	= SigmaCuCom75;
	sigma[ConducRot] 	= SigmaAlum75;

	sigma[Nucleo]	= 2.42e6;   
	rho[]		 	= 1/sigma[]; 			

/******************************************************************************************/
/******************************************************************************************/

	/*** PseudoReluctancia por Laminacin ***/

	d     	= 0.5e-3;				// Espesor de la laminacin en [m]
	stack 	= d^2/12;
	
/******************************************************************************************/
/******************************************************************************************/

	largo		= 249.0e-3;

	Ns[]		= 100;				// Nmero de espiras del devanado del estator (valor de prueba)
	Sc[]		= 94.31e-6;				// Seccin del devanado del estator (valor de prueba)

	Vnom[]	= 400*Sqrt[2/3];			// Tensin aplicada al devanado del estator

	Jnom		= 1.52;				// Densidad de corriente efectiva en [A/mm^2]

	Jnom_in[]  	= -Jnom*1e6*Sqrt[2];		// Densidad de corriente mxima en [A/m^2]
	Jnom_out[]	=  Jnom*1e6*Sqrt[2];

	phi		= 2*Pi/3;
	freq		= 50;
	ws		= 2*Pi*freq;

	phaseA	= ws*TimeInit;			//* **** En TimeStep (Res) Fase=0 **** En Harmonic (Ini) Fase=wt **** */
	phaseB	= phaseA-phi;
	phaseC	= phaseA+phi;

/******************************************************************************************/
/******************************************************************************************/

	VecUnitR[] = Unit[Vector[ $X, $Y, 0]];
	VecUnitT[] = Unit[Vector[-$Y, $X, 0]];

	CompRT[]   = Vector[$1*VecUnitR[], $1*VecUnitT[], 0];
	CompR[]    = Vector[$1*VecUnitR[],             0, 0];
	CompT[]    = Vector[            0, $1*VecUnitT[], 0];

	RotatePZ[] = Rotate[ Vector[$X, $Y, $Z], 0,  0, $1 ] ; 

	RR[]       = Vector[Cos[($1/180.*Pi)#1]#2*$X-Sin[#1]#3*$Y, #3*$X+#2*$Y, $Z] ;     
	RRrad[]    = Vector[          Cos[$1#1]#2*$X-Sin[#1]#3*$Y, #3*$X+#2*$Y, $Z] ;     
}

